#[macro_use]
extern crate log;

pub mod internal;
pub mod macros;

#[doc(inline)]
pub use internal::public::{
  either,
  prelude,
};
